#!/bin/dash -e
# fluxbatgen.sh: generates the battery.menu file for
# fluxbox by parsing /proc for battery info
#
# fluxbatgen.sh
# Copyright (C) 2007 Steffen Wendzel <cdp(at)doomed-reality(dot)org>
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor,
#                        Boston, MA  02110-1301  USA

BP=/proc/acpi/battery/BAT0
DESTFILE=/var/tmp/fluxbat/battery.menu
TMPFILE=/var/tmp/fluxbat/battery.menu.tmp

CURSTAT=`grep "remaining capacity:" $BP/state | sed 's/\ //' | sed 's/://' | \
	awk '{
		if ($1 == "remainingcapacity") {
			print $2
		}
	}'`
MAXSTAT=`grep "design capacity:" $BP/info | sed 's/\ //' | sed 's/://' | \
	awk '{
		if ($1 == "designcapacity") {
			print $2
		}
	}'`

PERC="`echo "scale=2; (${CURSTAT} / ${MAXSTAT})*100"|bc`"

echo '[begin] (BatteryMon)
[submenu] (BatteryMon '${PERC}'%)
	[separator]
	[nop] (Battery: '${PERC}'%)
	[exec] (More Info) {xterm -e "vi /proc/acpi/battery/BAT0/state"}
	[separator]
[end]
[end]
' > ${TMPFILE}

MD5SUM_OLD=`md5sum ${DESTFILE} | awk '{print $1}'`
MD5SUM_NEW=`md5sum ${TMPFILE} | awk '{print $1}'`
mv ${TMPFILE} ${DESTFILE}

WITHOUT_FLOAT=`echo $PERC|tr '.' 'M' | sed 's/M..//'`
if [ "$WITHOUT_FLOAT" -lt "5" ]; then
	xmessage 'FluxBat: Warning: BATTERY STATE VERY VERY LOW!'
fi

# reload config file only if something has changed
if [ "$MD5SUM_OLD" != "$MD5SUM_NEW" ]; then
	pkill -SIGUSR2 fluxbox
fi

